/*
 *  ircd-ratbox: A slightly useful ircd.
 *  spy_admin_notice.c: Sends a notice when someone uses ADMIN.
 *
 *  Copyright (C) 2002 by the past and present ircd coders, and others.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 *  USA
 *
 *  $Id: spy_admin_notice.c,v 1.9.4.1 2003/06/26 14:01:05 androsyn Exp $
 */
#include "stdinc.h"
#include "modules.h"
#include "hook.h"
#include "client.h"
#include "ircd.h"
#include "send.h"

int show_admin(struct hook_spy_data *);
int show_motd(struct hook_spy_data *);
int show_stats(struct hook_stats_data *);
int show_trace(struct hook_spy_data *);
int show_info(struct hook_spy_data *);
int show_links(struct hook_links_data *);
void
_modinit(void)
{
  hook_add_hook("doing_admin", (hookfn *)show_admin);
  hook_add_hook("doing_motd", (hookfn *)show_motd);
  hook_add_hook("doing_stats", (hookfn *)show_stats);
  hook_add_hook("doing_trace", (hookfn *)show_trace);
  hook_add_hook("doing_info", (hookfn *)show_info);
  hook_add_hook("doing_links", (hookfn *)show_links);
}

void
_moddeinit(void)
{
  hook_del_hook("doing_admin", (hookfn *)show_admin);
  hook_del_hook("doing_motd", (hookfn *)show_motd);
  hook_del_hook("doing_stats", (hookfn *)show_stats);
  hook_del_hook("doing_trace", (hookfn *)show_trace);
  hook_del_hook("doing_info", (hookfn *)show_info);
  hook_del_hook("doing_links", (hookfn *)show_links);
}

const char *_version = "$Revision: 1.9.4.2 $";

int show_admin(struct hook_spy_data *data)
{
  sendto_realops_flags(UMODE_SPY, L_ALL,
                         "Administration Information requested by \002%s\002(%s@%s) on server \037%s\037",
                         data->source_p->name, data->source_p->username,
                         data->source_p->host, data->source_p->user->server);

  return 0;
}
int show_motd(struct hook_spy_data *data)
{
  sendto_realops_flags(UMODE_SPY, L_ALL,
                         "Message of the Day requested by \002%s\002(%s@%s) on server \037%s\037",
                         data->source_p->name, data->source_p->username,
                         data->source_p->host, data->source_p->user->server);

  return 0;
}
int show_stats(struct hook_stats_data *data)
{
  if((data->statchar == 'L') || (data->statchar == 'l'))
    {
      if(data->name != NULL)
	sendto_realops_flags(UMODE_SPY, L_ALL,
			     "Statistics (%c) requested by \002%s\002(%s@%s) on server \037%s\037 for user %s",
			     data->statchar,
			     data->source_p->name,
			     data->source_p->username,
			     data->source_p->host,
			     data->source_p->user->server,
			     data->name);
      else
	sendto_realops_flags(UMODE_SPY, L_ALL,
			    "Statistics (%c) requested by \002%s\002(%s@%s) on server \037%s\037",
			     data->statchar,
			     data->source_p->name,
			     data->source_p->username,
			     data->source_p->host,
			     data->source_p->user->server);
    }
  else
    {
      sendto_realops_flags(UMODE_SPY, L_ALL,
               "Statistics (%c) requested by \002%s\002(%s@%s) on server \037%s\037",
			   data->statchar, data->source_p->name, data->source_p->username,
			   data->source_p->host, data->source_p->user->server);
    }

  return 0;
}
int show_trace(struct hook_spy_data *data)
{
  sendto_realops_flags(UMODE_SPY, L_ALL,
                         "Trace requested by \002%s\002(%s@%s) on server \037%s\037",
                         data->source_p->name, data->source_p->username,
                         data->source_p->host, data->source_p->user->server);

  return 0;
}
int show_info(struct hook_spy_data *data)
{
  sendto_realops_flags(UMODE_SPY, L_ALL,
                         "Server Information requested by \002%s\002(%s@%s) on server \037%s\037",
                         data->source_p->name, data->source_p->username,
                         data->source_p->host, data->source_p->user->server);

  return 0;
}
int show_links(struct hook_links_data *data)
{
  sendto_realops_flags(UMODE_SPY, L_ALL,
                         "Network Link Structure Information (Mask: %s) requested by \002%s\002(%s@%s) on server \037%s\037",
                         data->mask, data->source_p->name, data->source_p->username,
                         data->source_p->host, data->source_p->user->server);

  return 0;
}
